@@ -3,7 +3,6 @@
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 #
-# pyre-strict
 """
 Provides helpers for CLI interaction.
 """
@@ -58,7 +57,6 @@ def invoke_formatter(formatter_args: Sequence[str], code: AnyStr) -> AnyStr:
             formatter_args,
             env={},
             input=code,
-            stderr=subprocess.STDOUT,
             universal_newlines=not work_with_bytes,
             encoding=None if work_with_bytes else "utf-8",
         ),
